@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.h,v 1.7 2006/03/12 14:04:11 chpe Exp $
+ *  $Id: ephy-gui.h,v 1.8 2006/04/09 20:23:03 chpe Exp $
  */
 
 #ifndef EPHY_GUI_H
@@ -74,6 +74,11 @@ void		ephy_gui_help				 (GtkWindow *parent,
 							  const char *file_name,
 							  const char *link_id);
 
+void		ephy_gui_help_with_doc_id		 (GtkWindow *parent,
+							  const char *doc_id,
+							  const char *file_name,
+							  const char *link_id);
+
 void		ephy_gui_window_update_user_time	 (GtkWidget *window,
 							  guint32 user_time);
 
